#edit-tracking-url { min-width: 600px; }

.form-item-tracking-number label,
.form-item-tracking-note label,
.simple-package-tracking-numbers-label,
.simple-package-tracking-form { width: 100% !important; clear: both; }

.form-item-tracking-carrier { margin-bottom: 0px !important; }

.simple-package-tracking-form .form-item {
  margin-bottom: 0px;
}

.simple-package-tracking-form .form-type-checkbox {
  padding-top: 5px;
  padding-bottom: 5px;
}
